@@ -106,7 +106,7 @@ except ImportError:
     Crypto = AES = None
     import pyaes  # https://github.com/ricmoo/pyaes
 
-version_tuple = (1, 2, 8)
+version_tuple = (1, 2, 10)
 version = __version__ = '%d.%d.%d' % version_tuple
 __author__ = 'jasonacox'
 
@@ -436,6 +436,7 @@ class XenonDevice(object):
         self.version = 3.1
         self.retry = True
         self.dev_type = dev_type
+        self.disabledetect = False  # if True do not detect device22
         self.port = 6668  # default - do not expect caller to pass in
         self.socket = None
         self.socketPersistent = False
@@ -593,11 +594,11 @@ class XenonDevice(object):
         # and return payload decrypted
         try:
             msg = unpack_message(data)
-            # Data available seqno cmd retcode payload crc
+            # Data available: seqno cmd retcode payload crc
             log.debug("raw unpacked message = %r", msg)
             result = self._decode_payload(msg.payload)
         except:
-            log.debug("unexpected result unpacking tuya payload")
+            log.debug("error unpacking or decoding tuya JSON payload")
             result = error_json(ERR_PAYLOAD)
 
         # Did we detect a device22 device? Return ERR_DEVTYPE error.
@@ -636,7 +637,14 @@ class XenonDevice(object):
 
             log.debug('decrypted 3.3 payload=%r', payload)
             # Try to detect if device22 found
-            if "data unvalid" in payload:
+            log.debug("payload type = %s" % type(payload))
+            if not isinstance(payload, str):
+                try:
+                    payload = payload.decode()
+                except:
+                    log.debug("payload was not string type and decoding failed")
+                    return error_json(ERR_JSON,payload)
+            if not self.disabledetect and "data unvalid" in payload:
                 self.dev_type = "device22"
                 # set at least one DPS
                 self.dps_to_request = {"1": None}
@@ -901,7 +909,7 @@ class Device(XenonDevice):
         data = self._send_receive(payload)
         log.debug('status() received data=%r', data)
         # Error handling 
-        if 'Err' in data:
+        if data and 'Err' in data:
             if data['Err'] == str(ERR_DEVTYPE):
                 # Device22 detected and change - resend with new payload
                 log.debug('status() rebuilding payload for device22')
@@ -1678,6 +1686,7 @@ def deviceScan(verbose=False, maxretry=MAXCOUNT, color=True, poll=True):
         with open(DEVICEFILE) as f:
             tuyadevices = json.load(f)
             havekeys = True
+            log.debug('loaded=%s [%d devices]' % (DEVICEFILE, len(tuyadevices)))
     except:
         # No Device info
         pass
@@ -1724,6 +1733,7 @@ def deviceScan(verbose=False, maxretry=MAXCOUNT, color=True, poll=True):
     spinnerx = 0
     spinner = "|/-\\|"
 
+    log.debug('listening for UDP 6666 and 6667')
     while (count + counts) <= maxretry:
         note = 'invalid'
         if(verbose):
@@ -1765,7 +1775,7 @@ def deviceScan(verbose=False, maxretry=MAXCOUNT, color=True, poll=True):
                 result = result.decode()
 
             result = json.loads(result)
-            log.debug("Valid UDP Packet: %r" % result)
+            log.debug("Received valid UDP packet: %r" % result)
 
             note = 'Valid'
             ip = result['ip']
@@ -1858,7 +1868,7 @@ def deviceScan(verbose=False, maxretry=MAXCOUNT, color=True, poll=True):
     if(verbose):
         print("                    \n%sScan Complete!  Found %s devices.\n" %
               (normal, len(devices)))
-
+    log.debug("Scan complete with %s devices found" % len(devices))
     clients.close()
     client.close()
     return(devices)
